@@ -148,7 +148,8 @@ static struct usb_bus* init_usb()
   /* Workaround a libusb 0.1 bug : bus location is not initialised */
   busses = usb_get_busses();
   for (bus = busses; bus != NULL; bus = bus->next) {
-    bus->location = strtoul(bus->dirname, NULL, 10);
+    if (!bus->location)
+      bus->location = strtoul(bus->dirname, NULL, 10);
   }
   return (busses);
 }
@@ -176,7 +177,7 @@ static mtpdevice_list_t *append_to_mtpdevice_list(mtpdevice_list_t *devlist,
   new_list_entry->libusb_device = newdevice;
   new_list_entry->bus_location = bus_location;
   new_list_entry->next = NULL;
-  
+
   if (devlist == NULL) {
     return new_list_entry;
   } else {
@@ -192,7 +193,7 @@ static mtpdevice_list_t *append_to_mtpdevice_list(mtpdevice_list_t *devlist,
 /**
  * Small recursive function to free dynamic memory allocated to the linked list
  * of USB MTP devices
- * @param devlist dynamic linked list of pointers to usb devices with MTP 
+ * @param devlist dynamic linked list of pointers to usb devices with MTP
  * properties.
  * @return nothing
  */
@@ -228,12 +229,16 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
   unsigned char buf[1024], cmd;
   int i;
   int ret;
-  
-  /* Don't examine hubs (no point in that) */
-  if (dev->descriptor.bDeviceClass == USB_CLASS_HUB) {
+
+  /*
+   * Don't examine hubs or HID devices, no point in that.
+   * (Some Kensington mice really don't like this.)
+   */
+  if (dev->descriptor.bDeviceClass == USB_CLASS_HUB ||
+      dev->descriptor.bDeviceClass == USB_CLASS_HID) {
     return 0;
   }
-  
+
   /* Attempt to open Device on this port */
   devh = usb_open(dev);
   if (devh == NULL) {
@@ -666,7 +671,7 @@ const char *get_playlist_extension(PTP_USB *ptp_usb)
 
 static void
 libusb_glue_debug (PTPParams *params, const char *format, ...)
-{  
+{
         va_list args;
 
         va_start (args, format);
@@ -679,7 +684,7 @@ libusb_glue_debug (PTPParams *params, const char *format, ...)
 		fflush (stderr);
 	}
         va_end (args);
-}  
+}
 
 static void
 libusb_glue_error (PTPParams *params, const char *format, ...)
@@ -1091,7 +1096,7 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 	usbdata.type	= htod16(PTP_USB_CONTAINER_DATA);
 	usbdata.code	= htod16(ptp->Code);
 	usbdata.trans_id= htod32(ptp->Transaction_ID);
-  
+
 	((PTP_USB*)params->data)->current_transfer_complete = 0;
 	((PTP_USB*)params->data)->current_transfer_total = size+PTP_USB_BULK_HDR_LEN;
 
@@ -1103,7 +1108,7 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 		/* For all camera devices. */
 		datawlen = (size<PTP_USB_BULK_PAYLOAD_LEN_WRITE)?size:PTP_USB_BULK_PAYLOAD_LEN_WRITE;
 		wlen = PTP_USB_BULK_HDR_LEN + datawlen;
-    
+
 		ret = handler->getfunc(params, handler->priv, datawlen, usbdata.payload.data, &gotlen);
 		if (ret != PTP_RC_OK)
 			return ret;
@@ -1171,7 +1176,7 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 	PTPUSBBulkContainer usbdata;
 	unsigned long	written;
 	PTP_USB *ptp_usb = (PTP_USB *) params->data;
-
+	int putfunc_ret;
 
 	LIBMTP_USB_DEBUG("GET DATA PHASE\n");
 
@@ -1212,32 +1217,33 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 			}
 		}
 		if (usbdata.length == 0xffffffffU) {
-			/* Copy first part of data to 'data' */
-      int putfunc_ret = 
-			handler->putfunc(
-				params, handler->priv, rlen - PTP_USB_BULK_HDR_LEN, usbdata.payload.data,
-				&written
-			);
-      if (putfunc_ret != PTP_RC_OK)
-        return putfunc_ret;
-			/* stuff data directly to passed data handler */
-			while (1) {
-				unsigned long readdata;
-				uint16_t xret;
+		  /* Copy first part of data to 'data' */
+		  putfunc_ret =
+		    handler->putfunc(
+				     params, handler->priv, rlen - PTP_USB_BULK_HDR_LEN, usbdata.payload.data,
+				     &written
+				     );
+		  if (putfunc_ret != PTP_RC_OK)
+		    return putfunc_ret;
 
-				xret = ptp_read_func(
-					PTP_USB_BULK_HS_MAX_PACKET_LEN_READ,
-					handler,
-					params->data,
-					&readdata,
-					0
-				);
-				if (xret != PTP_RC_OK)
-					return xret;
-				if (readdata < PTP_USB_BULK_HS_MAX_PACKET_LEN_READ)
-					break;
-			}
-			return PTP_RC_OK;
+		  /* stuff data directly to passed data handler */
+		  while (1) {
+		    unsigned long readdata;
+		    uint16_t xret;
+
+		    xret = ptp_read_func(
+					 PTP_USB_BULK_HS_MAX_PACKET_LEN_READ,
+					 handler,
+					 params->data,
+					 &readdata,
+					 0
+					 );
+		    if (xret != PTP_RC_OK)
+		      return xret;
+		    if (readdata < PTP_USB_BULK_HS_MAX_PACKET_LEN_READ)
+		      break;
+		  }
+		  return PTP_RC_OK;
 		}
 		if (rlen > dtoh32(usbdata.length)) {
 			/*
@@ -1282,13 +1288,14 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 			params->split_header_data = 1;
 
 		/* Copy first part of data to 'data' */
-    int putfunc_ret = 
-		handler->putfunc(
-			params, handler->priv, rlen - PTP_USB_BULK_HDR_LEN, usbdata.payload.data,
-			&written
-		);
-    if (putfunc_ret != PTP_RC_OK)
-      return putfunc_ret;
+		putfunc_ret =
+		  handler->putfunc(
+				   params, handler->priv, rlen - PTP_USB_BULK_HDR_LEN,
+				   usbdata.payload.data,
+				   &written
+				   );
+		if (putfunc_ret != PTP_RC_OK)
+		  return putfunc_ret;
 
 		if (FLAG_NO_ZERO_READS(ptp_usb) &&
 		    len+PTP_USB_BULK_HDR_LEN == PTP_USB_BULK_HS_MAX_PACKET_LEN_READ) {
@@ -1309,7 +1316,7 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 
 		  LIBMTP_INFO("Reading in zero packet after header\n");
 
-          zeroresult = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, &zerobyte, 0, ptp_usb->timeout);
+		  zeroresult = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, &zerobyte, 0, ptp_usb->timeout);
 
 		  if (zeroresult != 0)
 		    LIBMTP_INFO("LIBMTP panic: unable to read in zero packet, response 0x%04x", zeroresult);
@@ -1548,9 +1555,12 @@ static int init_ptp_usb (PTPParams* params, PTP_USB* ptp_usb, struct usb_device*
     // if it isn't explicitly set
     // See above, same issue with pthreads means that if this fails it is not
     // fatal
+    // However, this causes problems on Macs so disable here
+    #ifndef __APPLE__
     usbresult = usb_set_altinterface(device_handle, 0);
     if (usbresult)
       fprintf(stderr, "ignoring usb_claim_interface = %d", usbresult);
+    #endif
 
     if (FLAG_SWITCH_MODE_BLACKBERRY(ptp_usb)) {
       int ret;
