@@ -27,12 +27,35 @@
  * Modified by Linus Walleij
  *
  */
+#ifndef LIBUSB_GLUE_H
+#define LIBUSB_GLUE_H
 
 #include "ptp.h"
 #include <usb.h>
 #include "libmtp.h"
 #include "device-flags.h"
 
+/* Make functions available for C++ */
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+/**
+ * Debug macro
+ */
+#define LIBMTP_USB_DEBUG(format, args...) \
+  do { \
+    if ((LIBMTP_debug & LIBMTP_DEBUG_USB) != 0) \
+      fprintf(stdout, "LIBMTP %s[%d]: " format, __FUNCTION__, __LINE__, ##args); \
+  } while (0)
+
+#define LIBMTP_USB_DATA(buffer, length, base) \
+  do { \
+    if ((LIBMTP_debug & LIBMTP_DEBUG_DATA) != 0) \
+      data_dump_ascii (stdout, buffer, length, base); \
+  } while (0)
+
+
 #define USB_BULK_READ usb_bulk_read
 #define USB_BULK_WRITE usb_bulk_write
 
@@ -62,7 +85,7 @@ struct _PTP_USB {
 
 int open_device (int busn, int devn, short force, PTP_USB *ptp_usb, PTPParams *params, struct usb_device **dev);
 void dump_usbinfo(PTP_USB *ptp_usb);
-char const * const get_playlist_extension(PTP_USB *ptp_usb);
+const char *get_playlist_extension(PTP_USB *ptp_usb);
 void close_device(PTP_USB *ptp_usb, PTPParams *params);
 LIBMTP_error_number_t configure_usb_device(LIBMTP_raw_device_t *device, 
 					   PTPParams *params,
@@ -107,8 +130,20 @@ void get_usb_device_timeout(PTP_USB *ptp_usb, int *timeout);
   ((a)->rawdevice.device_entry.device_flags & DEVICE_FLAG_BROKEN_SEND_OBJECT_PROPLIST)
 #define FLAG_BROKEN_BATTERY_LEVEL(a) \
   ((a)->rawdevice.device_entry.device_flags & DEVICE_FLAG_BROKEN_BATTERY_LEVEL)
+#define FLAG_FLAC_IS_UNKNOWN(a) \
+  ((a)->rawdevice.device_entry.device_flags & DEVICE_FLAG_FLAC_IS_UNKNOWN)
+#define FLAG_UNIQUE_FILENAMES(a) \
+  ((a)->rawdevice.device_entry.device_flags & DEVICE_FLAG_UNIQUE_FILENAMES)
+#define FLAG_SWITCH_MODE_BLACKBERRY(a) \
+  ((a)->rawdevice.device_entry.device_flags & DEVICE_FLAG_SWITCH_MODE_BLACKBERRY)
 
 /* connect_first_device return codes */
 #define PTP_CD_RC_CONNECTED	0
 #define PTP_CD_RC_NO_DEVICES	1
 #define PTP_CD_RC_ERROR_CONNECTING	2
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif //  LIBUSB-GLUE_H
